@@ -7,6 +7,7 @@ from pathlib import Path
 
 SPIDER_TYPE = 1  # 爬虫的类型（1 airspider 2 分布式 spider）（非用户设置）
 BASE_PATH = Path(__file__).absolute().parent
+STRICT_FILTER = False  # 严格去重，会加锁，影响性能但精准
 
 '''MYSQL'''
 MYSQL_HOST = None
@@ -26,11 +27,8 @@ PG_CONFIG = {}  # 字典形式
 
 '''REDIS'''
 REDIS_DB = 0
-# REDIS_HOST = None
-# REDIS_PORT = None
-# REDIS_PWD = None
-REDIS_HOST = '127.0.0.1'
-REDIS_PORT = 6379
+REDIS_HOST = None
+REDIS_PORT = None
 REDIS_PWD = None
 REDIS_CLUSTER_NODES = None  # 如果有集群的情况下，优先集群
 REDIS_MAX_CONNECTIONS = 5  # redis 最大连接数
